@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/splitting_helper.h $
-// $Id: splitting_helper.h 57cf9e0 2022-04-19T14:55:15+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/splitting_helper.h $
+// $Id: splitting_helper.h 9242a81 2023-02-07T11:31:55+01:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
@@ -14,7 +14,7 @@
 
 #include <CGAL/license/Alpha_wrap_3.h>
 
-#include <CGAL/Alpha_wrap_3/internal/Alpha_wrap_AABB_traits.h>
+#include <CGAL/Alpha_wrap_3/internal/Alpha_wrap_AABB_geom_traits.h>
 
 #include <CGAL/AABB_tree/internal/AABB_traversal_traits.h>
 #include <CGAL/AABB_primitive.h>
@@ -167,7 +167,7 @@ struct AABB_tree_splitter_traits
   // The input face ID serves when traversing the tree, to avoid doing the same intersection()
   // on the same datum seen from different primitives.
   //
-  // Technically, FPM could type-erase the mesh and the VPM, as it currently forces all independant
+  // Technically, FPM could type-erase the mesh and the VPM, as it currently forces all independent
   // inputs to have the same types. This is not such much of an issue for the mesh type,
   // but it can be annoying for the VPM type.
   using ID = std::pair<std::size_t /*primitive ID*/, std::size_t /*input face ID*/>;
@@ -175,18 +175,18 @@ struct AABB_tree_splitter_traits
 
   // Primitive ID --> box vector pos --> Bounding Box
   using BPMB = internal::Vector_property_map<CGAL::Bbox_3>;
-  using BPM = CGAL::Property_map_binder<IDPM, BPMB>;
+  using BPM = CGAL::Compose_property_map<IDPM, BPMB>;
 
   // Primitive ID --> point vector pos --> Reference Point
   using RPPMB = internal::Vector_property_map<Point>;
-  using RPPM = CGAL::Property_map_binder<IDPM, RPPMB>;
+  using RPPM = CGAL::Compose_property_map<IDPM, RPPMB>;
 
   // Primitive ID --> Datum pos vector pos --> Datum pos --> Datum
   // The vector of data has size nf, but the vector of datum pos has size tree.size()
   using DPPMB = internal::Vector_property_map<std::size_t>; // pos --> Datum pos
-  using DPPM = CGAL::Property_map_binder<IDPM, DPPMB>; // PID --> Datum pos
+  using DPPM = CGAL::Compose_property_map<IDPM, DPPMB>; // PID --> Datum pos
   using DPMB = internal::Vector_property_map<Triangle_3>; // Datum pos --> Datum
-  using DPM = CGAL::Property_map_binder<DPPM, DPMB>; // PID --> Datum
+  using DPM = CGAL::Compose_property_map<DPPM, DPMB>; // PID --> Datum
 
   using Primitive = CGAL::AABB_primitive<ID, DPM, RPPM,
                                          CGAL::Tag_true /*external pmaps*/,
@@ -236,7 +236,7 @@ public:
     :
       m_sq_alpha(square(alpha)),
       m_dppmb(), m_bpm(), m_rppm(), m_dpmb(),
-      m_dpm(DPPM(m_dppmb/*first binder's value_map*/)/*second binder's key map*/, m_dpmb)
+      m_dpm(DPPM(Default(), m_dppmb/*first binder's value_map*/)/*second binder's key map*/, m_dpmb)
   { }
 
 protected:
