@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Cartesian_kernel/include/CGAL/Cartesian_converter.h $
-// $Id: Cartesian_converter.h 3a0a4a6 2021-12-17T12:22:40+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Cartesian_kernel/include/CGAL/Cartesian_converter.h $
+// $Id: Cartesian_converter.h 1c5454d 2022-10-27T11:42:13+02:00 Laurent Rineau
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -30,6 +30,7 @@
 #include <CGAL/Bbox_2.h>
 #include <CGAL/Bbox_3.h>
 #include <CGAL/Origin.h>
+#include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/Kernel/Type_mapper.h>
 #include <vector>
 #include <boost/mpl/lambda.hpp>
@@ -108,6 +109,12 @@ public:
         return n;
     }
 
+    Return_base_tag
+    operator()(Return_base_tag o) const
+    {
+        return o;
+    }
+
     const Bbox_2&
     operator()(const Bbox_2& b) const
     {
@@ -129,7 +136,7 @@ public:
     template <typename T>
     T
     operator()(const T t,
-               typename std::enable_if<std::is_fundamental<T>::value>::type* = nullptr) const
+               std::enable_if_t<std::is_fundamental<T>::value>* = nullptr) const
     {
         return t;
     }
