@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Combinatorial_map/include/CGAL/Combinatorial_map_storages.h $
-// $Id: Combinatorial_map_storages.h 46f5325 2022-01-27T10:36:22+01:00 Guillaume Damiand
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Combinatorial_map/include/CGAL/Combinatorial_map_storages.h $
+// $Id: Combinatorial_map_storages.h fbd8b8a 2022-07-27T16:28:59+02:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -34,16 +34,14 @@ namespace CGAL {
     struct Container_type;
   }
 
-  /** @file Combinatorial_map_storages.h
-   * Definition of storages for dD Combinatorial map.
-   */
   // Storage of darts with compact container, beta with handles
-  template<unsigned int d_, class Items_, class Alloc_, class Concurrent_tag >
+  template<unsigned int d_, class Items_, class Alloc_>
   class Combinatorial_map_storage_1
   {
   public:
-    typedef Combinatorial_map_storage_1<d_, Items_, Alloc_, Concurrent_tag> Self;
-    typedef CGAL::Tag_false Use_index;
+    using Self=Combinatorial_map_storage_1<d_, Items_, Alloc_>;
+    using Use_index=CGAL::Tag_false;
+    using Concurrent_tag=typename internal::Get_concurrent_tag<Items_>::type;
 
     typedef internal::Combinatorial_map_helper<Self>      Helper;
 
@@ -61,12 +59,14 @@ namespace CGAL {
     typedef typename internal::Container_type
                  <Concurrent_tag, Dart, Dart_allocator>::type Dart_container;
 
-    typedef typename Dart_container::iterator              Dart_handle;
-    typedef typename Dart_container::const_iterator        Dart_const_handle;
+    typedef typename Dart_container::iterator              Dart_descriptor;
+    typedef typename Dart_container::const_iterator        Dart_const_descriptor;
     typedef typename Dart_container::size_type             size_type;
 
-    typedef std::nullptr_t Null_handle_type;
-    static const Null_handle_type null_handle;
+    typedef std::nullptr_t Null_descriptor_type;
+    CGAL_CPP17_INLINE static constexpr Null_descriptor_type null_descriptor=nullptr;
+
+    using Type_for_compact_container=void*;
 
     typedef Items_ Items;
     typedef Alloc_ Alloc;
@@ -74,7 +74,7 @@ namespace CGAL {
     struct Container_for_attributes :
       public internal::Container_type
                      <Concurrent_tag, T,
-                      typename std::allocator_traits<Alloc_>::template rebind_alloc<T>>::type
+                      typename Allocator_traits::template rebind_alloc<T>>::type
     {};
     /// Typedef for attributes
     typedef typename internal::template Get_attributes_tuple<Dart_wrapper>::type
@@ -84,11 +84,11 @@ namespace CGAL {
     struct Attribute_type: public Helper::template Attribute_type<i>
     {};
     template<int i>
-    struct Attribute_handle: public Helper::template Attribute_handle<i>
+    struct Attribute_descriptor: public Helper::template Attribute_descriptor<i>
     {};
     template<int i>
-    struct Attribute_const_handle:
-      public Helper::template Attribute_const_handle<i>
+    struct Attribute_const_descriptor:
+      public Helper::template Attribute_const_descriptor<i>
     {};
     template<int i>
     struct Attribute_range: public Helper::template Attribute_range<i>
@@ -98,6 +98,17 @@ namespace CGAL {
       public Helper::template Attribute_const_range<i>
     {};
 
+    /// Deprecated types, keep for now for backward compatibility
+    using Dart_handle=Dart_descriptor;
+    using Dart_const_handle=Dart_const_descriptor;
+
+    template<int i>
+    using Attribute_handle=Attribute_descriptor<i>;
+    template<int i>
+    using Attribute_const_handle=Attribute_const_descriptor<i>;
+
+    CGAL_CPP17_INLINE static constexpr Null_descriptor_type null_handle=null_descriptor;
+
     /// Number of marks
     static const size_type NB_MARKS = 32;
 
@@ -106,87 +117,112 @@ namespace CGAL {
 
     typedef Handle_hash_function Hash_function;
 
+    typedef Dart_container       Dart_range;
+    typedef const Dart_container Dart_const_range;
+    /// @return a Dart_range (range through all the darts of the map).
+    Dart_range& darts()             { return mdarts;}
+    Dart_const_range& darts() const { return mdarts; }
+
     // Init
     void init_storage()
     {
       // emplace null_dart; initialized in Combinatorial_map class
-      null_dart_handle = mnull_dart_container.emplace();
+      null_dart_descriptor = mnull_dart_container.emplace();
+      null_dart_handle=null_dart_descriptor;
     }
 
-   /** Return if this dart is free for adimension.
+    void clear_storage()
+    {
+      mnull_dart_container.clear();
+    }
+
+    /** Test if the map is empty.
+     *  @return true iff the map is empty.
+     */
+    bool is_empty() const
+    { return mdarts.empty(); }
+
+    /// @return the number of darts.
+    size_type number_of_darts() const
+    { return mdarts.size(); }
+
+    size_type upper_bound_on_dart_ids() const
+    { return 0; }
+
+    /** Return if this dart is free for adimension.
      * @param dh a dart handle
      * @param i the dimension.
-     * @return true iff dh is linked with nullptr for \em adimension.
+     * @return true iff dh is linked with null_dart_descriptor for \em adimension.
      */
     template<unsigned int i>
-    bool is_free(Dart_const_handle dh) const
+    bool is_free(Dart_const_descriptor dh) const
     {
       CGAL_assertion( dh!=nullptr );
       CGAL_assertion(i <= dimension);
-      return dh->mf[i]==null_dart_handle;
+      return dh->mf[i]==null_dart_descriptor;
     }
-    bool is_free(Dart_const_handle dh, unsigned int i) const
+    bool is_free(Dart_const_descriptor dh, unsigned int i) const
     {
       CGAL_assertion( dh!=nullptr );
       CGAL_assertion(i <= dimension);
-      return dh->mf[i]==null_dart_handle;
+      return dh->mf[i]==null_dart_descriptor;
     }
-    bool is_perforated(Dart_const_handle /*dh*/) const
+    bool is_perforated(Dart_const_descriptor /*dh*/) const
     { return false; }
 
     /// Set simultaneously all the marks of this dart to a given value.
-    void set_dart_marks(Dart_const_handle ADart,
+    void set_dart_marks(Dart_const_descriptor ADart,
                         const std::bitset<NB_MARKS>& amarks) const
     {
       CGAL_assertion( ADart!=nullptr );
       ADart->set_marks(amarks);
     }
     /// Return all the marks of a dart.
-    std::bitset<NB_MARKS> get_dart_marks(Dart_const_handle ADart) const
+    std::bitset<NB_MARKS> get_dart_marks(Dart_const_descriptor ADart) const
     {
       CGAL_assertion( ADart!=nullptr );
       return ADart->get_marks();
     }
     /// Return the mark value of dart a given mark number.
-    bool get_dart_mark(Dart_const_handle ADart, size_type amark) const
+    bool get_dart_mark(Dart_const_descriptor ADart, size_type amark) const
     {
       CGAL_assertion( ADart!=nullptr );
       return ADart->get_mark(amark);
     }
 
     /// Set the mark of a given mark number to a given value.
-    void set_dart_mark(Dart_const_handle ADart, size_type amark, bool avalue) const
+    void set_dart_mark(Dart_const_descriptor ADart, size_type amark, bool avalue) const
     {
       CGAL_assertion( ADart!=nullptr );
       ADart->set_mark(amark, avalue);
     }
 
     /// Flip the mark of a given mark number to a given value.
-    void flip_dart_mark(Dart_const_handle ADart, size_type amark) const
+    void flip_dart_mark(Dart_const_descriptor ADart, size_type amark) const
     {
       CGAL_assertion( ADart!=nullptr );
       ADart->flip_mark(amark);
     }
 
     // Access to beta maps
-    Dart_handle get_beta(Dart_handle ADart, int B1)
+    Dart_descriptor get_beta(Dart_descriptor ADart, int B1)
     {
       CGAL_assertion(ADart!=nullptr && B1>=0 && B1<=(int)dimension);
       return ADart->mf[B1];
     }
-    Dart_const_handle get_beta(Dart_const_handle ADart, int B1) const
+    Dart_const_descriptor get_beta(Dart_const_descriptor ADart, int B1) const
     {
       CGAL_assertion(ADart!=nullptr && B1>=0 && B1<=(int)dimension);
       return  ADart->mf[B1];
     }
     template<int B1>
-    Dart_handle get_beta(Dart_handle ADart)
+    Dart_descriptor get_beta(Dart_descriptor ADart)
     {
       CGAL_assertion(ADart!=nullptr && B1>=0 && B1<=(int)dimension);
       return  ADart->mf[B1];
     }
     template<int B1>
-    Dart_const_handle get_beta(Dart_const_handle ADart) const
+    Dart_const_descriptor get_beta(Dart_const_descriptor ADart) const
     {
       CGAL_assertion(ADart!=nullptr && B1>=0 && B1<=(int)dimension);
       return  ADart->mf[B1];
@@ -194,31 +230,31 @@ namespace CGAL {
 
     // return a handle on the i-attribute
     template<unsigned int i>
-    typename Attribute_handle<i>::type attribute(Dart_handle ADart)
+    typename Attribute_descriptor<i>::type attribute(Dart_descriptor ADart)
     {
       CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
                      "attribute<i> called but i-attributes are disabled.");
       return std::get<Helper::template Dimension_index<i>::value>
-        (ADart->mattribute_handles);
+        (ADart->mattribute_descriptors);
     }
     template<unsigned int i>
-    typename Attribute_const_handle<i>::type
-    attribute(Dart_const_handle ADart) const
+    typename Attribute_const_descriptor<i>::type
+    attribute(Dart_const_descriptor ADart) const
     {
       CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
                      "attribute<i> called but i-attributes are disabled.");
       return std::get<Helper::template Dimension_index<i>::value>
-        (ADart->mattribute_handles);
+        (ADart->mattribute_descriptors);
     }
 
     // Copy a given attribute
     template<unsigned int i>
-    typename Attribute_handle<i>::type copy_attribute
-    (typename Attribute_const_handle<i>::type ah)
+    typename Attribute_descriptor<i>::type copy_attribute
+    (typename Attribute_const_descriptor<i>::type ah)
     {
       CGAL_static_assertion_msg(Helper::template Dimension_index<i>::value>=0,
                      "copy_attribute<i> called but i-attributes are disabled.");
-      typename Attribute_handle<i>::type res=
+      typename Attribute_descriptor<i>::type res=
         std::get<Helper::template Dimension_index<i>::value>
         (mattribute_containers).emplace(*ah);
       this->template init_attribute_ref_counting<i>(res);
@@ -227,7 +263,7 @@ namespace CGAL {
 
     // Test if a given attribute is valid
     template<unsigned int i>
-    bool is_valid_attribute(typename Attribute_const_handle<i>::type ah) const
+    bool is_valid_attribute(typename Attribute_const_descriptor<i>::type ah) const
     {
       CGAL_assertion( ah!=nullptr );
       return ah->is_valid();
@@ -236,25 +272,25 @@ namespace CGAL {
     // accessors and modifiers to the attribute ref counting given its handle
     template<unsigned int i>
     std::size_t get_attribute_ref_counting
-    (typename Attribute_const_handle<i>::type ah) const
+    (typename Attribute_const_descriptor<i>::type ah) const
     {
       CGAL_assertion( ah!=nullptr );
       return ah->get_nb_refs();
     }
     template<unsigned int i>
-    void init_attribute_ref_counting(typename Attribute_handle<i>::type ah)
+    void init_attribute_ref_counting(typename Attribute_descriptor<i>::type ah)
     {
       CGAL_assertion( ah!=nullptr );
       ah->mrefcounting=0;
     }
     template<unsigned int i>
-    void inc_attribute_ref_counting(typename Attribute_handle<i>::type ah)
+    void inc_attribute_ref_counting(typename Attribute_descriptor<i>::type ah)
     {
       CGAL_assertion( ah!=nullptr );
       ah->inc_nb_refs();
     }
     template<unsigned int i>
-    void dec_attribute_ref_counting(typename Attribute_handle<i>::type ah)
+    void dec_attribute_ref_counting(typename Attribute_descriptor<i>::type ah)
     {
       CGAL_assertion( ah!=nullptr );
       ah->dec_nb_refs();
@@ -263,14 +299,14 @@ namespace CGAL {
     // get the attribute given its handle
     template<unsigned int i>
     typename Attribute_type<i>::type&
-    get_attribute(typename Attribute_handle<i>::type ah)
+    get_attribute(typename Attribute_descriptor<i>::type ah)
     {
       CGAL_assertion( ah!=nullptr );
       return *ah;
     }
     template<unsigned int i>
     const typename Attribute_type<i>::type&
-    get_attribute(typename Attribute_const_handle<i>::type ah) const
+    get_attribute(typename Attribute_const_descriptor<i>::type ah) const
     {
       CGAL_assertion( ah!=nullptr );
       return *ah;
@@ -278,14 +314,14 @@ namespace CGAL {
 
     // Get the dart of the given attribute
     template<unsigned int i>
-    Dart_handle dart_of_attribute(typename Attribute_handle<i>::type ah)
+    Dart_descriptor dart_of_attribute(typename Attribute_descriptor<i>::type ah)
     {
       CGAL_assertion( ah!=nullptr );
       return ah->dart();
     }
     template<unsigned int i>
-    Dart_const_handle
-    dart_of_attribute(typename Attribute_const_handle<i>::type ah) const
+    Dart_const_descriptor
+    dart_of_attribute(typename Attribute_const_descriptor<i>::type ah) const
     {
       CGAL_assertion( ah!=nullptr );
       return ah->dart();
@@ -293,30 +329,30 @@ namespace CGAL {
 
     // Set the dart of the given attribute
     template<unsigned int i>
-    void set_dart_of_attribute(typename Attribute_handle<i>::type ah,
-                               Dart_handle adart)
+    void set_dart_of_attribute(typename Attribute_descriptor<i>::type ah,
+                               Dart_descriptor adart)
     {
       CGAL_assertion( ah!=nullptr );
       ah->set_dart(adart);
     }
 
     // Get the information associated with a given dart
-    Dart_info& info(Dart_handle adart)
+    Dart_info& info(Dart_descriptor adart)
     { return adart->info(); }
-    const Dart_info& info(Dart_const_handle adart) const
+    const Dart_info& info(Dart_const_descriptor adart) const
     { return adart->info(); }
 
     // Get the info of the given attribute
     template<unsigned int i>
     typename Attribute_type<i>::type::Info &
-    info_of_attribute(typename Attribute_handle<i>::type ah)
+    info_of_attribute(typename Attribute_descriptor<i>::type ah)
     {
       CGAL_assertion( ah!=nullptr );
       return ah->info();
     }
     template<unsigned int i>
     const typename Attribute_type<i>::type::Info &
-    info_of_attribute(typename Attribute_const_handle<i>::type ah) const
+    info_of_attribute(typename Attribute_const_descriptor<i>::type ah) const
     {
       CGAL_assertion( ah!=nullptr );
       return ah->info();
@@ -324,7 +360,7 @@ namespace CGAL {
 
     // Get the info of the i-cell attribute associated with the given dart
     template<unsigned int i>
-    typename Attribute_type<i>::type::Info & info(Dart_handle adart)
+    typename Attribute_type<i>::type::Info & info(Dart_descriptor adart)
     {
       CGAL_assertion( adart!=nullptr );
       CGAL_assertion( attribute<i>(adart)!=nullptr );
@@ -332,7 +368,7 @@ namespace CGAL {
     }
     template<unsigned int i>
     const typename Attribute_type<i>::type::Info &
-    info(Dart_const_handle adart) const
+    info(Dart_const_descriptor adart) const
     {
       CGAL_assertion( adart!=nullptr );
       CGAL_assertion( attribute<i>(adart)!=nullptr );
@@ -341,14 +377,14 @@ namespace CGAL {
 
     // Get the dart of the i-cell attribute associated with the given dart
     template<unsigned int i>
-    Dart_handle dart(Dart_handle adart)
+    Dart_descriptor dart(Dart_descriptor adart)
     {
       CGAL_assertion( adart!=nullptr );
       CGAL_assertion( attribute<i>(adart)!=nullptr );
       return dart_of_attribute<i>(attribute<i>(adart));
     }
     template<unsigned int i>
-    Dart_const_handle dart(Dart_const_handle adart) const
+    Dart_const_descriptor dart(Dart_const_descriptor adart) const
     {
       CGAL_assertion( adart!=nullptr );
       CGAL_assertion( attribute<i>(adart)!=nullptr );
@@ -356,22 +392,26 @@ namespace CGAL {
     }
 
     // Debug function
-    void display_dart(Dart_const_handle ADart) const
+    void display_dart(Dart_const_descriptor ADart) const
     { std::cout<<mdarts.index(ADart); }
 
     template<unsigned int i>
-    void display_attribute(typename Attribute_const_handle<i>::type ah) const
+    void display_attribute(typename Attribute_const_descriptor<i>::type ah) const
     { std::cout<< std::get<Helper::template Dimension_index<i>::value>
         (mattribute_containers).index(ah); }
 
+    template <unsigned int i>
+    size_type upper_bound_on_attribute_ids() const
+    { return 0; }
+
   protected:
     // Set the handle on the i th attribute
     template<unsigned int i>
-    void basic_set_dart_attribute(Dart_handle dh,
-                                  typename Attribute_handle<i>::type ah)
+    void basic_set_dart_attribute(Dart_descriptor dh,
+                                  typename Attribute_descriptor<i>::type ah)
     {
       std::get<Helper::template Dimension_index<i>::value>
-        (dh->mattribute_handles) = ah;
+        (dh->mattribute_descriptors) = ah;
     }
 
     /** Link a dart with a given dart for a given dimension.
@@ -380,18 +420,18 @@ namespace CGAL {
      * @param i the dimension.
      */
     template<unsigned int i>
-    void dart_link_beta(Dart_handle adart, Dart_handle adart2)
+    void dart_link_beta(Dart_descriptor adart, Dart_descriptor adart2)
     {
       CGAL_assertion(i <= dimension);
       CGAL_assertion(adart!=nullptr && adart2!=nullptr);
-      CGAL_assertion(adart!=null_dart_handle);
+      CGAL_assertion(adart!=null_dart_descriptor);
       adart->mf[i] = adart2;
     }
-    void dart_link_beta(Dart_handle adart, Dart_handle adart2, unsigned int i)
+    void dart_link_beta(Dart_descriptor adart, Dart_descriptor adart2, unsigned int i)
     {
       CGAL_assertion(i <= dimension);
       CGAL_assertion(adart!=nullptr && adart2!=nullptr);
-      CGAL_assertion(adart!=null_dart_handle);
+      CGAL_assertion(adart!=null_dart_descriptor);
       adart->mf[i] = adart2;
     }
 
@@ -400,36 +440,42 @@ namespace CGAL {
      * @param i the dimension.
      */
     template<unsigned int i>
-    void dart_unlink_beta(Dart_handle adart)
+    void dart_unlink_beta(Dart_descriptor adart)
     {
       CGAL_assertion(adart!=nullptr && i <= dimension);
-      adart->mf[i] = null_dart_handle;
+      adart->mf[i] = null_dart_descriptor;
     }
-    void dart_unlink_beta(Dart_handle adart, unsigned int i)
+    void dart_unlink_beta(Dart_descriptor adart, unsigned int i)
     {
       CGAL_assertion(adart!=nullptr && i <= dimension);
-      adart->mf[i] = null_dart_handle;
+      adart->mf[i] = null_dart_descriptor;
     }
 
   public:
-    /// Void dart. A dart d is i-free if beta_i(d)=null_dart_handle.
-    Dart_handle null_dart_handle; // Todo Dart_const_handle ??
+    /// Void dart. A dart d is i-free if beta_i(d)=null_dart_descriptor.
+    Dart_descriptor null_dart_descriptor; // Todo Dart_const_descriptor ??
+    Dart_descriptor null_dart_handle; // Deprecated: kept for backward compatibility
 
   protected:
     /// Dart container.
     Dart_container mdarts;
 
-    /// Container for the null_dart_handle.
+    /// Container for the null_dart_descriptor.
     Dart_container mnull_dart_container;
 
     /// Tuple of attributes containers
     typename Helper::Attribute_containers mattribute_containers;
   };
 
-  /// null_handle
-  template < unsigned int d_, class Items_, class Alloc_, class Concurrent_tag >
-  const typename Combinatorial_map_storage_1<d_, Items_, Alloc_, Concurrent_tag>::Null_handle_type
-  Combinatorial_map_storage_1<d_, Items_, Alloc_, Concurrent_tag>::null_handle = nullptr;
+#ifndef CGAL_CXX17
+  template<unsigned int d_, class Items_, class Alloc_>
+  constexpr typename Combinatorial_map_storage_1<d_, Items_, Alloc_>::Null_descriptor_type
+  Combinatorial_map_storage_1<d_, Items_, Alloc_>::null_descriptor;
+
+  template<unsigned int d_, class Items_, class Alloc_>
+  constexpr typename Combinatorial_map_storage_1<d_, Items_, Alloc_>::Null_descriptor_type
+  Combinatorial_map_storage_1<d_, Items_, Alloc_>::null_handle;
+#endif
 
 } // namespace CGAL
 
