@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Envelope_3/include/CGAL/Envelope_3/Envelope_divide_and_conquer_3.h $
-// $Id: Envelope_divide_and_conquer_3.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Envelope_3/include/CGAL/Envelope_3/Envelope_divide_and_conquer_3.h $
+// $Id: Envelope_divide_and_conquer_3.h 6e6598c 2023-10-10T19:32:59+02:00 Jane Tournois
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Michal Meyerovitch     <gorgymic@post.tau.ac.il>
@@ -38,7 +38,7 @@
 #ifdef CGAL_ENVELOPE_USE_BFS_FACE_ORDER
 #include <CGAL/Arr_face_index_map.h>
 #include <CGAL/graph_traits_dual_arrangement_on_surface_2.h>
-#include <CGAL/boost/graph/dijkstra_shortest_paths.h>
+#include <boost/graph/dijkstra_shortest_paths.hpp>
 #endif
 
 // this base divide & conquer algorithm splits the input into 2 groups,
@@ -183,7 +183,7 @@ public:
   }
 
   // compute the envelope of surfaces in 3D, using the default arbitrary
-  // dividor
+  // divider
   template <class SurfaceIterator>
   void construct_lu_envelope(SurfaceIterator begin, SurfaceIterator end,
                              Minimization_diagram_2& result)
@@ -193,7 +193,7 @@ public:
   }
 
 
-  // compute the envelope of surfaces in 3D using the given set dividor
+  // compute the envelope of surfaces in 3D using the given set divider
   template <class SurfaceIterator, class SetDividor>
   void construct_lu_envelope(SurfaceIterator begin, SurfaceIterator end,
                              Minimization_diagram_2& result,
@@ -219,7 +219,7 @@ public:
   }
 
   // compute the envelope of xy-monotone surfaces in 3D,
-  // using the default arbitrary dividor
+  // using the default arbitrary divider
   template <class SurfaceIterator>
   void construct_envelope_xy_monotone(SurfaceIterator begin,
                                       SurfaceIterator end,
@@ -230,7 +230,7 @@ public:
   }
 
   // compute the envelope of xy-monotone surfaces in 3D using the given
-  // set dividor
+  // set divider
   template <class SurfaceIterator, class SetDividor>
   void construct_envelope_xy_monotone(SurfaceIterator begin,
                                       SurfaceIterator end,
@@ -366,7 +366,7 @@ protected:
             he->twin()->face()->set_no_data();
           }
 
-          // init auxiliary data for f and its boundarys.
+          // init auxiliary data for f and its boundaries.
           for(Outer_ccb_iterator ocit = f->outer_ccbs_begin();
               ocit != f->outer_ccbs_end(); ocit++){
             Ccb_halfedge_circulator face_hec = *ocit;
@@ -475,7 +475,7 @@ public:
     {
       Halfedge_handle hh = ei;
       // there must be data from at least one map, because all the surfaces
-      // are continous
+      // are continuous
       if (!get_aux_is_set(hh, 0) || !get_aux_is_set(hh, 1))
         continue;
       CGAL_assertion(get_aux_is_set(hh, 0));
@@ -604,7 +604,7 @@ public:
       if (vh->is_decision_set())
         continue;
       // there must be data from at least one map, because all the surfaces
-      // are continous
+      // are continuous
       CGAL_assertion(get_aux_is_set(vh, 0));
       CGAL_assertion(get_aux_is_set(vh, 1));
       CGAL_assertion(!aux_has_no_data(vh, 1) || !aux_has_no_data(vh, 0));
