@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/HalfedgeDS/include/CGAL/HalfedgeDS_decorator.h $
-// $Id: HalfedgeDS_decorator.h 0d66e19 2020-07-24T17:05:10+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/HalfedgeDS/include/CGAL/HalfedgeDS_decorator.h $
+// $Id: HalfedgeDS_decorator.h 4547818 2022-11-15T13:39:40+01:00 albert-github
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -427,7 +427,7 @@ public:
         insert_tip( inew->opposite(), hnew);
         insert_tip( jnew->opposite(), inew);
         insert_tip( hnew->opposite(), jnew);
-        // Make the new incidences with the old stucture.
+        // Make the new incidences with the old structure.
         CGAL_assertion_code( std::size_t termination_count = 0;)
         if ( h->next() != i) {
             Halfedge_handle g = h->next();
@@ -795,8 +795,7 @@ public:
         Assert_compile_time_tag(Supports_vertex_halfedge(), Tag_true());
         Assert_compile_time_tag(Supports_halfedge_vertex(), Tag_true());
 
-        unsigned int nb_erased_components = 0,
-                     nb_isolated_vertices = 0;
+        unsigned int nb_erased_components = 0;
 
         // Gets list of connected components, ordered by size (i.e. number of vertices)
         std::vector<Vertex_handle> components;
@@ -818,13 +817,9 @@ public:
           else // if isolated vertex
           {
             vertices_erase(vertex);
-            nb_isolated_vertices++;
           }
         }
 
-//         if (nb_isolated_vertices > 0)
-//           std::cerr << "  Erased " << nb_isolated_vertices << " isolated vertices\n";
-
         return nb_erased_components;
     }
 
