@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org);
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Stream_support/include/CGAL/IO/3MF.h $
-// $Id: 3MF.h fb6f703 2021-05-04T14:07:49+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Stream_support/include/CGAL/IO/3MF.h $
+// $Id: 3MF.h 8a0b214 2023-04-11T17:38:37+02:00 albert-github
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Maxime Gimeno
@@ -23,12 +23,12 @@
 #endif
 
 #include <boost/range/value_type.hpp>
-#include <boost/utility/enable_if.hpp>
 
 #include <functional>
 #include <iostream>
 #include <string>
 #include <vector>
+#include <type_traits>
 
 #if defined(CGAL_LINKED_WITH_3MF) || defined(DOXYGEN_RUNNING)
 
@@ -447,7 +447,7 @@ bool read_3MF(const std::string& fname,
  * \param fname the name of the 3mf file to write
  * \param all_points a `PointRanges` that contains the points of the soups to write
  * \param all_triangles a `TriangleRanges` that contains the triangles of the soups in `fname`
- * \param names a range of std::string` associating a name to each soup, which will appear in the output
+ * \param names a range of `std::string` associating a name to each soup, which will appear in the output
  *
  * \return `true` if the writing is successful, `false` otherwise.
  */
@@ -504,7 +504,7 @@ bool write_3MF(const std::string& fname,
 
 template<typename PointRange, typename TriangleRange>
 bool write_3MF(const std::string& fname, const PointRange& points, const TriangleRange& triangles,
-               typename boost::enable_if<internal::is_Range<PointRange> >::type* = nullptr)
+               std::enable_if_t<internal::is_Range<PointRange>::value>* = nullptr)
 {
   return write_triangle_soup_to_3mf(fname, points, triangles, "anonymous");
 }
