@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Intersections_3/include/CGAL/Intersections_3/internal/Bbox_3_Iso_cuboid_3_do_intersect.h $
-// $Id: Bbox_3_Iso_cuboid_3_do_intersect.h 9c6456f 2021-07-29T14:23:40+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Intersections_3/include/CGAL/Intersections_3/internal/Bbox_3_Iso_cuboid_3_do_intersect.h $
+// $Id: Bbox_3_Iso_cuboid_3_do_intersect.h 3a4e230 2022-11-22T12:22:42+01:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -23,9 +23,10 @@ namespace Intersections {
 namespace internal {
 
 template <class K>
-bool do_intersect(const CGAL::Bbox_3& bb,
-                  const typename K::Iso_cuboid_3& ic,
-                  const K& /* k */)
+typename K::Boolean
+do_intersect(const CGAL::Bbox_3& bb,
+             const typename K::Iso_cuboid_3& ic,
+             const K& /* k */)
 {
   // use CGAL::compare to access the Coercion_traits between K::FT and double
   if(compare(bb.xmax(), ic.xmin()) == SMALLER || compare(ic.xmax(), bb.xmin()) == SMALLER)
@@ -38,9 +39,10 @@ bool do_intersect(const CGAL::Bbox_3& bb,
 }
 
 template <class K>
-bool do_intersect(const typename K::Iso_cuboid_3& ic,
-                  const CGAL::Bbox_3& bb,
-                  const K& k)
+typename K::Boolean
+do_intersect(const typename K::Iso_cuboid_3& ic,
+             const CGAL::Bbox_3& bb,
+             const K& k)
 {
   return do_intersect(bb, ic, k);
 }
