@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Mesh_3/include/CGAL/Mesh_3/Robust_intersection_traits_3.h $
-// $Id: Robust_intersection_traits_3.h 5945e48 2021-09-17T08:14:06+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Mesh_3/include/CGAL/Mesh_3/Robust_intersection_traits_3.h $
+// $Id: Robust_intersection_traits_3.h 820b1c5 2023-07-26T17:30:40+02:00 Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -94,7 +94,7 @@ struct Vector_plane_orientation_3_static_filter :
         fit_in_double(get_approx(b).z(), bz) &&
         fit_in_double(get_approx(c).x(), cx) && fit_in_double(get_approx(c).y(), cy) &&
         fit_in_double(get_approx(c).z(), cz))
-    { // This bloc is not indented because it was added in a second step,
+    { // This block is not indented because it was added in a second step,
       // and one wants to avoid the reindentation of the whole code
 
     double abx = bx - ax;
@@ -418,14 +418,14 @@ tr_intersection(const typename K::Triangle_3  &t,
 
   typedef typename K::Point_3 Point_3;
 
-  typename K::Construct_vertex_3 vertex_on =
-    k.construct_vertex_3_object();
-
+  typename K::Do_intersect_3 do_intersect =
+    k.do_intersect_3_object();
   typename K::Orientation_3 orientation =
     k.orientation_3_object();
-
   typename K::Construct_point_on_3 point_on =
     k.construct_point_on_3_object();
+  typename K::Construct_vertex_3 vertex_on =
+    k.construct_vertex_3_object();
 
   typename Mesh_3::Vector_plane_orientation_3_static_filter<K> vector_plane_orient;
 
@@ -439,17 +439,24 @@ tr_intersection(const typename K::Triangle_3  &t,
   const Point_3& q = point_on(r,1);
 
   const Orientation ray_direction = vector_plane_orient(p, q, a, b, c);
-
-  if(ray_direction == COPLANAR) return result_type();
+  if(ray_direction == COPLANAR)
+    return result_type();
 
   const Orientation abcp = orientation(a,b,c,p);
+  if(abcp == COPLANAR) // p belongs to the triangle's supporting plane
+  {
+    if(do_intersect(t, p))
+      return result_type(p);
+    else
+      return result_type();
+  }
 
-  if(abcp == COPLANAR) return result_type(); // p belongs to the triangle's
-                                        // supporting plane
-
-  if(ray_direction == abcp) return result_type();
-  // The ray lies entirely in one of the two open halfspaces defined by the
-  // triangle's supporting plane.
+  if(ray_direction == abcp)
+  {
+    // The ray lies entirely in one of the two open halfspaces defined by the
+    // triangle's supporting plane.
+    return result_type();
+  }
 
   // Here we know that the ray crosses the plane (abc)
 
