@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Point_set_3/include/CGAL/Point_set_3.h $
-// $Id: Point_set_3.h 0fb05d1 2022-11-15T20:04:23+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Point_set_3/include/CGAL/Point_set_3.h $
+// $Id: Point_set_3.h 32da839 2023-12-14T15:26:44+01:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -35,6 +35,49 @@
 
 namespace CGAL {
 
+template <typename Point,
+          typename Vector = typename Kernel_traits<Point>::Kernel::Vector_3>
+class Point_set_3;
+
+/// \cond SKIP_IN_MANUAL
+namespace internal {
+  template<typename Point, typename Vector>
+  class Point_set_3_index
+  {
+  public:
+#ifdef CGAL_POINT_SET_3_USE_STD_SIZE_T_AS_SIZE_TYPE
+    typedef std::size_t size_type;
+#else
+    typedef boost::uint32_t size_type;
+#endif
+    typedef CGAL::Point_set_3<Point, Vector> Point_set_3;
+
+  private:
+    friend class CGAL::Point_set_3<Point, Vector>;
+    friend class Properties::Property_container<Point_set_3, Point_set_3_index>;
+    template <class> friend class Properties::Property_array;
+    template <class> friend struct Property_map;
+    friend class std::vector<Point_set_3_index>;
+    size_type value;
+
+  public:
+    Point_set_3_index(const Point_set_3_index& index) : value(static_cast<size_type>(index)) { }
+    Point_set_3_index(const std::size_t& value) : value(static_cast<size_type>(value)) { }
+    Point_set_3_index() : value(static_cast<size_type>(-1)) { }
+    Point_set_3_index operator= (const Point_set_3_index& index) { value = index.value; return *this; }
+
+    operator std::size_t() const { return static_cast<std::size_t>(value); }
+    bool operator== (const Point_set_3_index& index) const { return value == index.value; }
+    bool operator!= (const Point_set_3_index& index) const { return value != index.value; }
+    bool operator<  (const Point_set_3_index& index) const { return value < index.value; }
+    Point_set_3_index& operator++ () { ++value; return *this; }
+    Point_set_3_index& operator-- () { --value; return *this; }
+    Point_set_3_index operator++ (int) { Point_set_3_index tmp(*this); ++value; return tmp; }
+    Point_set_3_index operator-- (int) { Point_set_3_index tmp(*this); --value; return tmp; }
+};
+} // namespace internal
+/// \endcond
+
 /*!
 
   \ingroup PkgPointSet3Ref
@@ -48,23 +91,23 @@ namespace CGAL {
   two particular properties that are hard coded by this class: the
   coordinates of the points and the normal vectors.
 
-  The coordinates of a point can be access using the index of the
+  The coordinates of a point can be accessed using the index of the
   point and the member function `point()`. This property is always
   present. The normal vector of a point can be accessed using the
   index of the point and the `normal()` method. This property must
   be explicitly created.
 
   All properties can be accessed as a range using the methods
-  `points()`, `normals()`, and `range()` for points coordinates,
+  `points()`, `normals()`, and `range()` for point coordinates,
   normal vectors, and other properties respectively.
 
-  Removing a point with properties is achieved by moving its `Index`
+  Removing a point with properties is achieved by moving its index
   at the end of the container and keeping track of the number of
   removed elements. A garbage collection method must be called to
   really remove it from memory.
 
   For convenience, all functions of the package \ref
-  PkgPointSetProcessing3 automatically creates the right named
+  PkgPointSetProcessing3 automatically create the right named
   parameters if called with a `CGAL::Point_set_3` object as argument.
 
 
@@ -75,7 +118,7 @@ namespace CGAL {
  */
 
 template <typename Point,
-          typename Vector = typename Kernel_traits<Point>::Kernel::Vector_3>
+          typename Vector>
 class Point_set_3
 {
 public:
@@ -85,7 +128,7 @@ public:
   typedef Vector Vector_type;
   typedef Point_set_3<Point, Vector> Point_set;
 
-  class Index;
+  using Index = internal::Point_set_3_index<Point, Vector>;
 
   typedef typename Properties::Property_container<Point_set, Index> Base;
 
@@ -105,45 +148,15 @@ public:
   };
   /// \endcond
 
-  /*!
-    \brief This represents a point with associated properties.
-    \cgalModels `::Index`
-    \cgalModels `LessThanComparable`
-    \cgalModels `Hashable`
+#ifdef DOXYGEN_RUNNING
+   /*!
+  \brief This represents a point with associated properties.
+  \cgalModels `::Index`
+  \cgalModels `LessThanComparable`
+  \cgalModels `Hashable`
   */
-  class Index
-  {
-    /// \cond SKIP_IN_MANUAL
-  public:
-#ifdef CGAL_POINT_SET_3_USE_STD_SIZE_T_AS_SIZE_TYPE
-    typedef std::size_t size_type;
-#else
-    typedef boost::uint32_t size_type;
+  class Index;
 #endif
-  private:
-    friend class Point_set_3;
-    friend class Properties::Property_container<Point_set_3, Index>;
-    template <class> friend class Properties::Property_array;
-    template <class> friend struct Property_map;
-    friend class std::vector<Index>;
-    size_type value;
-
-  public:
-    Index (const Index& index) : value (static_cast<size_type>(index)) { }
-    Index (const std::size_t& value) : value (static_cast<size_type>(value)) { }
-    Index () : value (static_cast<size_type>(-1)) { }
-    Index operator= (const Index& index) { value = index.value; return *this; }
-    /// \cond SKIP_IN_MANUAL
-    operator std::size_t() const { return static_cast<std::size_t>(value); }
-    bool operator== (const Index& index) const { return value == index.value; }
-    bool operator!= (const Index& index) const { return value != index.value; }
-    bool operator<  (const Index& index) const { return value < index.value; }
-    Index& operator++ () { ++ value; return *this; }
-    Index& operator-- () { -- value; return *this; }
-    Index operator++ (int) { Index tmp(*this); ++ value; return tmp; }
-    Index operator-- (int) { Index tmp(*this); -- value; return tmp; }
-    /// \endcond
-  };
 
   typedef Point Point_3; ///< The point type
   typedef Vector Vector_3; ///< The vector type
@@ -694,7 +707,6 @@ public:
     \sa `number_of_removed_points()`
   */
   std::size_t garbage_size () const { return number_of_removed_points(); }
-  /// \endcond
 
   /*!  \brief returns `true` if there are elements marked as removed,
     `false` otherwise.
@@ -966,8 +978,8 @@ public:
     - `geom_traits`: contains the kernel `typename Kernel_traits<Point>`::`Kernel`
 
     \warning this method does not check if the normal map was
-    instanciated or not. The normal map named parameter should not be
-    used if this property was not instanciated first.
+    instantiated or not. The normal map named parameter should not be
+    used if this property was not instantiated first.
   */
 #ifdef DOXYGEN_RUNNING
   unspecified_type
@@ -1275,9 +1287,6 @@ private:
 
 }; // end of class Point_set_3
 
-
-
-
 /*!
 
   \brief Append `other` at the end of `ps`.
@@ -1303,8 +1312,8 @@ Point_set_3<Point, Vector>& operator+=(Point_set_3<Point, Vector>& ps,
 
 /// \cond SKIP_IN_MANUAL
 // specialization for default named parameters
-template <typename Point, typename Vector, typename NamedParameters, typename NP_TAG>
-struct Point_set_processing_3_np_helper<Point_set_3<Point, Vector>, NamedParameters, NP_TAG>
+template <typename Point, typename Vector, typename NamedParameters, typename DPM, typename DVM>
+struct Point_set_processing_3_np_helper<Point_set_3<Point, Vector>, NamedParameters, DPM, DVM>
 {
   typedef typename std::iterator_traits<typename Point_set_3<Point, Vector>::iterator>::value_type Value_type;
 
@@ -1313,9 +1322,9 @@ struct Point_set_processing_3_np_helper<Point_set_3<Point, Vector>, NamedParamet
   typedef typename Point_set_3<Point, Vector>::template Property_map<Point> DefaultPMap;
   typedef const typename Point_set_3<Point, Vector>::template Property_map<Point> DefaultConstPMap;
 
-  typedef typename internal_np::Lookup_named_param_def<NP_TAG,
+  typedef typename internal_np::Lookup_named_param_def<internal_np::point_t,
     NamedParameters,DefaultPMap> ::type  Point_map; // public
-  typedef typename internal_np::Lookup_named_param_def<NP_TAG,
+  typedef typename internal_np::Lookup_named_param_def<internal_np::point_t,
     NamedParameters,DefaultConstPMap> ::type  Const_point_map; // public
 
   typedef typename internal_np::Lookup_named_param_def <
@@ -1374,5 +1383,23 @@ struct Point_set_processing_3_np_helper<Point_set_3<Point, Vector>, NamedParamet
 
 } // namespace CGAL
 
+namespace boost {
+template <typename Point, typename Vector>
+std::size_t hash_value(const typename CGAL::internal::Point_set_3_index<Point, Vector>& i)
+{
+  return i;
+}
+} // namespace boost
+
+namespace std {
+template <typename Point, typename Vector>
+struct hash< CGAL::internal::Point_set_3_index<Point, Vector> > {
+  std::size_t operator()(const CGAL::internal::Point_set_3_index<Point, Vector>& i) const
+  {
+    std::size_t ret = i;
+    return ret;
+  }
+};
+} // namespace std
 
 #endif // CGAL_POINT_SET_3_H
