@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/GraphicsView/include/CGAL/Qt/Converter.h $
-// $Id: Converter.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/GraphicsView/include/CGAL/Qt/Converter.h $
+// $Id: Converter.h 42752d0 2023-03-29T11:39:37-03:00 Luiz Georg
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -167,6 +167,15 @@ public:
     return qp;
   }
 
+  QPolygonF operator()(const std::list< CGAL_Point_2 >& p) const
+  {
+    QPolygonF qp;
+    for(int i = 0; i < p.size(); i++){
+      qp << operator()(p[i]);
+    }
+    return qp;
+  }
+
 
   void operator()(std::list< CGAL_Point_2 >& p, const QPolygonF& qp) const
   {
